Struct ic_event_hub::types::TimestampedRemoteCallEndpoint
source · [−]pub struct TimestampedRemoteCallEndpoint {
pub timestamp: u64,
pub endpoint: RemoteCallEndpoint,
}Fields
timestamp: u64endpoint: RemoteCallEndpointTrait Implementations
sourceimpl Clone for TimestampedRemoteCallEndpoint
impl Clone for TimestampedRemoteCallEndpoint
sourcefn clone(&self) -> TimestampedRemoteCallEndpoint
fn clone(&self) -> TimestampedRemoteCallEndpoint
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl<'de> Deserialize<'de> for TimestampedRemoteCallEndpoint
impl<'de> Deserialize<'de> for TimestampedRemoteCallEndpoint
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Ord for TimestampedRemoteCallEndpoint
impl Ord for TimestampedRemoteCallEndpoint
sourceimpl PartialOrd<TimestampedRemoteCallEndpoint> for TimestampedRemoteCallEndpoint
impl PartialOrd<TimestampedRemoteCallEndpoint> for TimestampedRemoteCallEndpoint
sourcefn partial_cmp(&self, other: &Self) -> Option<Ordering>
fn partial_cmp(&self, other: &Self) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
sourcefn lt(&self, other: &Self) -> bool
fn lt(&self, other: &Self) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
sourcefn le(&self, other: &Self) -> bool
fn le(&self, other: &Self) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for TimestampedRemoteCallEndpoint
impl StructuralEq for TimestampedRemoteCallEndpoint